"""Contains general PyTorch utility methods."""


from . import nn, random


__all__ = ["nn", "random"]
